Module bot

Module bot 

Structs

BotCommand
This object represents a bot command.
Close
Use this method to close the bot instance before moving it from one local server to another. You need to delete the webhook before calling this method to ensure that the bot isn’t launched again after server restart. The method will return error 429 in the first 10 minutes after the bot is launched. Returns True on success. Requires no parameters.
DeleteMyCommands
Use this method to delete the list of the bot’s commands for the given scope and user language. After deletion, higher level commands will be shown to affected users. Returns True on success.
GetMe
A simple method for testing your bot’s auth token. Requires no parameters.
GetMyCommands
Use this method to get the current list of the bot’s commands for the given scope and user language. Returns Array of BotCommand on success. If commands aren’t set, an empty list is returned.
LogOut
Use this method to log out from the cloud Bot API server before launching the bot locally.
SetMyCommands
Use this method to change the list of the bot’s commands. See https://core.telegram.org/bots#commands for more details about bot commands. Returns True on success.

Enums

BotCommandScope
This object represents the scope to which bot commands are applied.