Struct telbot_types::bot::GetMe [−][src]
pub struct GetMe;Expand description
A simple method for testing your bot’s auth token. Requires no parameters.
Returns basic information about the bot in form of a User object.
pub struct GetMe;A simple method for testing your bot’s auth token. Requires no parameters.
Returns basic information about the bot in form of a User object.