GetMyCommands

Struct GetMyCommands 

pub struct GetMyCommands {
    pub scope: Option<BotCommandScope>,
    pub language_code: Option<String>,
}
Use this method to get the current list of the bot’s commands for the given scope and user language. Returns Array of BotCommand on success. If commands aren’t set, an empty list is returned.

Fields

scope: Option<BotCommandScope>

A JSON-serialized object, describing scope of users for which the commands are relevant. Defaults to BotCommandScopeDefault.

language_code: Option<String>

A two-letter ISO 639-1 language code. If empty, commands will be applied to all users from the given scope, for whose language there are no dedicated commands

Implementations

Source

impl GetMyCommands

pub fn new() -> Self

Create a new getMyCommands request

pub fn with_scope(self, scope: BotCommandScope) -> Self

Set command scope

pub fn with_language_code(self, language_code: impl Into<String>) -> Self

Set language code