Enum telbot_types::chat::ChatMember[][src]

pub enum ChatMember {
    Owner {
        user: User,
        is_anonymous: bool,
        custom_title: Option<String>,
    },
    Administrator {
Show 14 fields user: User, can_be_edited: bool, is_anonymous: bool, can_manage_chat: bool, can_delete_messages: bool, can_manage_voice_chats: bool, can_restrict_members: bool, can_promote_members: bool, can_change_info: bool, can_invite_users: bool, can_post_messages: Option<bool>, can_edit_messages: Option<bool>, can_pin_messages: Option<bool>, custom_title: Option<String>,
}, Member { user: User, }, Restricted { user: User, is_member: bool, can_change_info: bool, can_invite_users: bool, can_pin_messages: bool, can_send_messages: bool, can_send_media_messages: bool, can_send_polls: bool, can_send_other_messages: bool, can_add_web_page_previews: bool, until_date: u64, }, Left { user: User, }, Banned { user: User, until_date: u64, }, }

Variants

Owner

Represents a chat member that owns the chat and has all administrator privileges.

Fields of Owner

user: User

Information about the user

is_anonymous: bool

True, if the user’s presence in the chat is hidden

custom_title: Option<String>

Custom title for this user

Administrator

Represents a chat member that has some additional privileges.

Fields of Administrator

user: User

Information about the user

can_be_edited: bool

True, if the bot is allowed to edit administrator privileges of that user

is_anonymous: bool

True, if the user’s presence in the chat is hidden

can_manage_chat: bool

True, if the administrator can access the chat event log, chat statistics, message statistics in channels, see channel members, see anonymous administrators in supergroups and ignore slow mode. Implied by any other administrator privilege

can_delete_messages: bool

True, if the administrator can delete messages of other users

can_manage_voice_chats: bool

True, if the administrator can manage voice chats

can_restrict_members: bool

True, if the administrator can restrict, ban or unban chat members

can_promote_members: bool

True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that he has promoted, directly or indirectly (promoted by administrators that were appointed by the user)

can_change_info: bool

True, if the user is allowed to change the chat title, photo and other settings

can_invite_users: bool

True, if the user is allowed to invite new users to the chat

can_post_messages: Option<bool>

True, if the administrator can post in the channel; channels only

can_edit_messages: Option<bool>

True, if the administrator can edit messages of other users and can pin messages; channels only

can_pin_messages: Option<bool>

True, if the user is allowed to pin messages; groups and supergroups only

custom_title: Option<String>

Custom title for this user

Member

Represents a chat member that has no additional privileges or restrictions.

Fields of Member

user: User

Information about the user

Restricted

Represents a chat member that is under certain restrictions in the chat. Supergroups only.

Fields of Restricted

user: User

Information about the user

is_member: bool

True, if the user is a member of the chat at the moment of the request

can_change_info: bool

True, if the user is allowed to change the chat title, photo and other settings

can_invite_users: bool

True, if the user is allowed to invite new users to the chat

can_pin_messages: bool

True, if the user is allowed to pin messages

can_send_messages: bool

True, if the user is allowed to send text messages, contacts, locations and venues

can_send_media_messages: bool

True, if the user is allowed to send audios, documents, photos, videos, video notes and voice notes

can_send_polls: bool

True, if the user is allowed to send polls

can_send_other_messages: bool

True, if the user is allowed to send animations, games, stickers and use inline bots

can_add_web_page_previews: bool

True, if the user is allowed to add web page previews to their messages

until_date: u64

Date when restrictions will be lifted for this user; unix time. If 0, then the user is restricted forever

Left

Represents a chat member that isn’t currently a member of the chat, but may join it themselves.

Fields of Left

user: User

Information about the user

Banned

Represents a chat member that was banned in the chat and can’t return to the chat or view chat messages.

Fields of Banned

user: User

Information about the user

until_date: u64

Date when restrictions will be lifted for this user; unix time. If 0, then the user is banned forever