Chat

Struct Chat 

pub struct Chat {
Show 18 fields pub id: i64, pub kind: ChatKind, pub title: Option<String>, pub username: Option<String>, pub first_name: Option<String>, pub last_name: Option<String>, pub photo: Option<ChatPhoto>, pub bio: Option<String>, pub description: Option<String>, pub invite_link: Option<String>, pub pinned_message: Option<Box<Message>>, pub permissions: Option<ChatPermissions>, pub slow_mode_delay: Option<i32>, pub message_auto_delete_time: Option<i32>, pub sticker_set_name: Option<String>, pub can_get_sticker_set: Option<bool>, pub linked_chat_id: Option<i32>, pub location: Option<ChatLocation>,
}
This object represents a chat.

Fields

id: i64

Unique identifier for this chat.

kind: ChatKind

Type of chat.

title: Option<String>

Title, for supergroups, channels and group chats

username: Option<String>

Username, for private chats, supergroups and channels if available

first_name: Option<String>

First name of the other party in a private chat

last_name: Option<String>

Last name of the other party in a private chat

photo: Option<ChatPhoto>

Chat photo. Returned only in getChat.

bio: Option<String>

Bio of the other party in a private chat. Returned only in getChat.

description: Option<String>

Description, for groups, supergroups and channel chats. Returned only in getChat.

invite_link: Option<String>

Primary invite link, for groups, supergroups and channel chats. Returned only in getChat.

pinned_message: Option<Box<Message>>

The most recent pinned message (by sending date). Returned only in getChat.

permissions: Option<ChatPermissions>

Default chat member permissions, for groups and supergroups. Returned only in getChat.

slow_mode_delay: Option<i32>

Default chat member permissions, for groups and supergroups. Returned only in getChat.

message_auto_delete_time: Option<i32>

The time after which all messages sent to the chat will be automatically deleted; in seconds. Returned only in getChat.

sticker_set_name: Option<String>

For supergroups, name of group sticker set. Returned only in getChat.

can_get_sticker_set: Option<bool>

True, if the bot can change the group sticker set. Returned only in getChat.

linked_chat_id: Option<i32>

Unique identifier for the linked chat, i.e. the discussion group identifier for a channel and vice versa; for supergroups and channel chats. Returned only in getChat.

location: Option<ChatLocation>

For supergroups, the location to which the supergroup is connected. Returned only in getChat.

Implementations

Source

impl Chat

pub fn send_animation( &self, animation: impl Into<InputFileVariant>, ) -> SendAnimation

pub fn send_audio(&self, audio: impl Into<InputFileVariant>) -> SendAudio

pub fn send_chat_action(&self, action: ChatActionKind) -> SendChatAction

pub fn send_contact( &self, phone_number: impl Into<String>, first_name: impl Into<String>, ) -> SendContact

pub fn send_dice(&self) -> SendDice

pub fn send_document( &self, document: impl Into<InputFileVariant>, ) -> SendDocument

pub fn send_location( &self, latitude: f32, longitude: f32, horizontal_accuracy: f32, ) -> SendLocation

pub fn send_media_group(&self) -> SendMediaGroup

pub fn send_message(&self, text: impl Into<String>) -> SendMessage

pub fn send_photo(&self, photo: impl Into<InputFileVariant>) -> SendPhoto

pub fn send_poll( &self, question: impl Into<String>, options: Vec<String>, ) -> SendPoll

pub fn send_quiz( &self, question: impl Into<String>, options: Vec<String>, correct_option_id: u32, ) -> SendPoll

pub fn send_venue( &self, latitude: f32, longitude: f32, title: impl Into<String>, address: impl Into<String>, ) -> SendVenue

pub fn send_video(&self, video: impl Into<InputFileVariant>) -> SendVideo

pub fn send_video_note( &self, video_note: impl Into<InputFileVariant>, ) -> SendVideoNote

pub fn send_voice(&self, voice: impl Into<InputFileVariant>) -> SendVoice

pub fn ban(&self, user_id: i64) -> BanChatMember

pub fn unban(&self, user_id: i64) -> UnbanChatMember

pub fn restrict( &self, user_id: i64, permissions: ChatPermissions, ) -> RestrictChatMember

pub fn promote(&self, user_id: i64) -> PromoteChatMember

pub fn set_administrator_title( &self, user_id: i64, custom_title: impl Into<String>, ) -> SetChatAdministratorCustomTitle

pub fn set_permissions( &self, permissions: ChatPermissions, ) -> SetChatPermissions

pub fn approve_join(&self, user_id: i64) -> ApproveChatJoinRequest

pub fn decline_join(&self, user_id: i64) -> DeclineChatJoinRequest

pub fn set_photo(&self, photo: InputFile) -> SetChatPhoto

pub fn delete_photo(&self) -> DeleteChatPhoto

pub fn set_title(&self, title: impl Into<String>) -> SetChatTitle

pub fn set_description( &self, description: impl Into<String>, ) -> SetChatDescription

pub fn remove_description(&self) -> SetChatDescription

pub fn pin_message(&self, message_id: i64) -> PinChatMessage

pub fn unpin_message(&self, message_id: i64) -> UnpinChatMessage

pub fn unpin_latest_message(&self) -> UnpinChatMessage

pub fn unpin_all_messages(&self) -> UnpinAllChatMessages

pub fn leave(&self) -> LeaveChat

pub fn get_details(&self) -> GetChat

pub fn get_administrators(&self) -> GetChatAdministrators

pub fn get_member_count(&self) -> GetChatMemberCount

pub fn get_member(&self, user_id: i64) -> GetChatMember

pub fn set_sticker_set( &self, sticker_set_name: impl Into<String>, ) -> SetChatStickerSet

pub fn delete_sticker_set(&self) -> DeleteChatStickerSet

pub fn edit_text_of( &self, message_id: i64, text: impl Into<String>, ) -> EditMessageText

pub fn remove_caption_of(&self, message_id: i64) -> EditMessageCaption

pub fn edit_caption_of( &self, message_id: i64, caption: impl Into<String>, ) -> EditMessageCaption

pub fn edit_media_of( &self, message_id: i64, media: impl Into<InputMedia>, ) -> EditMessageMedia

pub fn remove_reply_markup_of(&self, message_id: i64) -> EditMessageReplyMarkup

pub fn edit_reply_markup_of( &self, message_id: i64, reply_markup: impl Into<InlineKeyboardMarkup>, ) -> EditMessageReplyMarkup

pub fn stop_poll(&self, message_id: i64) -> StopPoll

pub fn delete_message(&self, message_id: i64) -> DeleteMessage