Struct telbot_types::chat::ChatPermissions[][src]

pub struct ChatPermissions {
    pub can_send_messages: Option<bool>,
    pub can_send_media_messages: Option<bool>,
    pub can_send_polls: Option<bool>,
    pub can_send_other_messages: Option<bool>,
    pub can_add_web_page_previews: Option<bool>,
    pub can_change_info: Option<bool>,
    pub can_invite_users: Option<bool>,
    pub can_pin_messages: Option<bool>,
}
Describes actions that a non-administrator user is allowed to take in a chat.

Fields

can_send_messages: Option<bool>

True, if the user is allowed to send text messages, contacts, locations and venues

can_send_media_messages: Option<bool>

True, if the user is allowed to send audios, documents, photos, videos, video notes and voice notes, implies can_send_messages

can_send_polls: Option<bool>

True, if the user is allowed to send polls, implies can_send_messages

can_send_other_messages: Option<bool>

True, if the user is allowed to send animations, games, stickers and use inline bots, implies can_send_media_messages

can_add_web_page_previews: Option<bool>

True, if the user is allowed to add web page previews to their messages, implies can_send_media_messages

can_change_info: Option<bool>

True, if the user is allowed to change the chat title, photo and other settings. Ignored in public supergroups

can_invite_users: Option<bool>

True, if the user is allowed to invite new users to the chat

can_pin_messages: Option<bool>

True, if the user is allowed to pin messages. Ignored in public supergroups