pub struct DeclineChatJoinRequest {
pub chat_id: ChatId,
pub user_id: i64,
}Expand description
Use this method to decline a chat join request. The bot must be an administrator in the chat for this to work and must have the can_invite_users administrator right. Returns True on success.
Fields
chat_id: ChatIdUnique identifier for the target group or username of the target supergroup or channel (in the format @username)
user_id: i64Unique identifier of the target user
Implementations