pub struct EditChatInviteLink {
pub chat_id: ChatId,
pub invite_link: String,
pub name: Option<String>,
pub expire_date: Option<u64>,
pub member_limit: Option<u32>,
pub creates_join_request: Option<bool>,
}Expand description
Use this method to edit a non-primary invite link created by the bot. The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights. Returns the edited invite link as a ChatInviteLink object.
Fields
chat_id: ChatIdUnique identifier for the target group or username of the target supergroup or channel (in the format @username)
invite_link: StringThe invite link to edit
name: Option<String>Invite link name; 0-32 characters
expire_date: Option<u64>Point in time (Unix timestamp) when the link will expire
member_limit: Option<u32>Maximum number of users that can be members of the chat simultaneously after joining the chat via this invite link; 1-99999
creates_join_request: Option<bool>True, if users joining the chat via the link need to be approved by chat administrators. If True, member_limit can’t be specified
Implementations
Sourceimpl EditChatInviteLink
impl EditChatInviteLink
Sourcepub fn new(chat_id: impl Into<ChatId>, invite_link: impl Into<String>) -> Self
pub fn new(chat_id: impl Into<ChatId>, invite_link: impl Into<String>) -> Self
Create a new editChatInviteLink request
Sourcepub fn with_expire_date(self, expire_date: u64) -> Self
pub fn with_expire_date(self, expire_date: u64) -> Self
Set link expire date
Sourcepub fn with_member_limit(self, member_limit: u32) -> Self
pub fn with_member_limit(self, member_limit: u32) -> Self
Set link member limit
Sourcepub fn create_join_reqeuest(self) -> Self
pub fn create_join_reqeuest(self) -> Self
Set creates_join_request to true