pub struct GetChatMember {
pub chat_id: ChatId,
pub user_id: i64,
}Expand description
Use this method to get information about a member of a chat. Returns a ChatMember object on success.
Fields
chat_id: ChatIdUnique identifier for the target group or username of the target supergroup or channel (in the format @channelusername)
user_id: i64Unique identifier of the target user
Implementations