RestrictChatMember

Struct RestrictChatMember 

pub struct RestrictChatMember {
    pub chat_id: ChatId,
    pub user_id: i64,
    pub permissions: ChatPermissions,
    pub until_date: Option<u64>,
}
Use this method to restrict a user in a supergroup. The bot must be an administrator in the supergroup for this to work and must have the appropriate administrator rights. Pass True for all permissions to lift restrictions from a user. Returns True on success.

Fields

chat_id: ChatId

Unique identifier for the target group or username of the target supergroup or channel (in the format @channelusername)

user_id: i64

Unique identifier of the target user

permissions: ChatPermissions

A JSON-serialized object for new user permissions

until_date: Option<u64>

Date when restrictions will be lifted for the user, unix time. If user is restricted for more than 366 days or less than 30 seconds from the current time, they are considered to be restricted forever

Implementations

Source

impl RestrictChatMember

pub fn new( chat_id: impl Into<ChatId>, user_id: i64, permissions: ChatPermissions, ) -> Self

Create a new restrictChatMember request

pub fn until_date(self, date: u64) -> Self

Set the date at which the restriction wil be lifted