pub struct SetChatAdministratorCustomTitle {
pub chat_id: ChatId,
pub user_id: i64,
pub custom_title: String,
}Expand description
Use this method to set a custom title for an administrator in a supergroup promoted by the bot. Returns True on success.
Fields
chat_id: ChatIdUnique identifier for the target group or username of the target supergroup or channel (in the format @username)
user_id: i64Unique identifier of the target user
custom_title: StringNew custom title for the administrator; 0-16 characters, emoji are not allowed
Implementations