pub struct SetChatDescription {
pub chat_id: ChatId,
pub description: Option<String>,
}Expand description
Use this method to change the description of a group, a supergroup or a channel. The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights. Returns True on success.
Fields
chat_id: ChatIdUnique identifier for the target group or username of the target supergroup or channel (in the format @username)
description: Option<String>New chat description, 0-255 characters
Implementations