pub struct SetChatPermissions {
pub chat_id: ChatId,
pub permissions: ChatPermissions,
}Expand description
Use this method to set default chat permissions for all members. The bot must be an administrator in the group or a supergroup for this to work and must have the can_restrict_members administrator rights. Returns True on success.
Fields
chat_id: ChatIdUnique identifier for the target group or username of the target supergroup or channel (in the format @username)
permissions: ChatPermissionsA JSON-serialized object for new user permissions
Implementations
Sourceimpl SetChatPermissions
impl SetChatPermissions
Sourcepub fn new(chat_id: impl Into<ChatId>, permissions: ChatPermissions) -> Self
pub fn new(chat_id: impl Into<ChatId>, permissions: ChatPermissions) -> Self
Create a new setChatPermissions request