pub struct UnbanChatMember {
pub chat_id: ChatId,
pub user_id: i64,
pub only_if_banned: Option<bool>,
}Expand description
Use this method to unban a previously banned user in a supergroup or channel. The user will not return to the group or channel automatically, but will be able to join via link, etc. The bot must be an administrator for this to work. By default, this method guarantees that after the call the user is not a member of the chat, but will be able to join it. So if the user is a member of the chat they will also be removed from the chat. If you don’t want this, use the parameter only_if_banned. Returns True on success.
Fields
chat_id: ChatIdUnique identifier for the target group or username of the target supergroup or channel (in the format @username)
user_id: i64Unique identifier of the target user
only_if_banned: Option<bool>Do nothing if the user is not banned
Implementations