Module telbot_types::file [−][src]
Structs
This object represents an animation file (GIF or H.264/MPEG-4 AVC video without sound).
This object represents an audio file to be treated as music by the Telegram clients.
This object represents a general file (as opposed to photos, voice messages and audio files).
This object represents a file ready to be downloaded.
Use this method to get basic info about a file and prepare it for downloading.
For the moment, bots can download files of up to 20MB in size.
On success, a File object is returned.
The file can then be downloaded via the link https://api.telegram.org/file/bot<token>/<file_path>, where <file_path> is taken from the response.
It is guaranteed that the link will be valid for at least 1 hour.
When the link expires, a new one can be requested by calling getFile again.
This object represents a video file.
This object represents a video message (available in Telegram apps as of v.4.0).
This object represents a voice note.
Enums
Thumbnail type.
This object represents the content of a media message to be sent. It should be one of