Struct telbot_types::file::PhotoSize [−][src]
pub struct PhotoSize {
pub file_id: String,
pub file_unique_id: String,
pub width: u32,
pub height: u32,
pub file_size: u32,
}Fields
file_id: StringIdentifier for this file, which can be used to download or reuse the file
file_unique_id: StringUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
width: u32Photo width
height: u32Photo height
file_size: u32File size