Upon receiving a message with this object, Telegram clients will display a reply interface to the user
(act as if the user has selected the bot’s message and tapped ‘Reply’).
This object represents one button of the reply keyboard.
For simple text buttons String can be used instead of this object to specify text of the button.
Optional fields request_contact, request_location, and request_poll are mutually exclusive.