pub struct InlineKeyboardMarkup {
pub inline_keyboard: Vec<Vec<InlineKeyboardButton>>,
}Expand description
This object represents an inline keyboard that appears right next to the message it belongs to.
Fields
inline_keyboard: Vec<Vec<InlineKeyboardButton>>Array of button rows, each represented by an Array of InlineKeyboardButton objects
Implementations
Sourceimpl InlineKeyboardMarkup
impl InlineKeyboardMarkup
Sourcepub fn new_with_row(row: InlineKeyboardRow) -> Self
pub fn new_with_row(row: InlineKeyboardRow) -> Self
Create a new InlineKeyboardMarkup with a row.
Sourcepub fn with_row(self, row: InlineKeyboardRow) -> Self
pub fn with_row(self, row: InlineKeyboardRow) -> Self
Add a row