Struct telbot_types::markup::KeyboardButtonPollType [−][src]
pub struct KeyboardButtonPollType { /* fields omitted */ }Expand description
This object represents type of a poll, which is allowed to be created and sent when the corresponding button is pressed.