pub struct ReplyKeyboardRemove {
pub selective: Option<bool>,
/* private fields */
}Expand description
Upon receiving a message with this object, Telegram clients will remove the current custom keyboard and display the default letter-keyboard.
By default, custom keyboards are displayed until a new keyboard is sent by a bot. An exception is made for one-time keyboards that are hidden immediately after the user presses a button (see ReplyKeyboardMarkup).
Fields
selective: Option<bool>Use this parameter if you want to show the keyboard to specific users only.
Targets:
- users that are @mentioned in the text of the Message object;
- if the bot’s message is a reply (has reply_to_message_id), sender of the original message.
Example: A user requests to change the bot’s language, bot replies to the request with a keyboard to select the new language. Other users in the group don’t see the keyboard.