Struct telbot_types::message::Dice[][src]

pub struct Dice {
    pub emoji: String,
    pub value: i32,
}
This object represents an animated emoji that displays a random value.

Fields

emoji: String

Emoji on which the dice throw animation is based

value: i32

Value of the dice, 1-6 for “🎲”, “🎯” and “🎳” base emoji, 1-5 for “🏀” and “⚽” base emoji, 1-64 for “🎰” base emoji