Struct telbot_types::message::EditMessageLiveLocation [−][src]
pub struct EditMessageLiveLocation {
pub target: ChatOrInlineMessage,
pub latitude: f32,
pub longitude: f32,
pub horizontal_accuracy: Option<f32>,
pub heading: Option<u32>,
pub proximity_alert_radius: Option<u32>,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to edit live location messages. A location can be edited until its live_period expires or editing is explicitly disabled by a call to stopMessageLiveLocation. On success, if the edited message is not an inline message, the edited Message is returned, otherwise True is returned.
Fields
target: ChatOrInlineMessageIdentifier of the message to edit
latitude: f32Latitude of new location
longitude: f32Longitude of new location
horizontal_accuracy: Option<f32>The radius of uncertainty for the location, measured in meters; 0-1500
heading: Option<u32>For live locations, a direction in which the user is moving, in degrees. Must be between 1 and 360 if specified.
proximity_alert_radius: Option<u32>For live locations, a maximum distance for proximity alerts about approaching another chat member, in meters. Must be between 1 and 100000 if specified.
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for a new inline keyboard.
Implementations
Create a new editMessageLiveLocation request from chat message id
Create a new editMessageLiveLocation request from inline message id
Set horizontal accuracy
Set heading
Set proximity alert radius
Set reply markup