pub struct EditMessageMedia {
pub chat_id: ChatId,
pub message_id: i64,
pub media: InputMedia,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to edit animation, audio, document, photo, or video messages. If a message is part of a message album, then it can be edited only to an audio for audio albums, only to a document for document albums and to a photo or a video otherwise. When an inline message is edited, a new file can’t be uploaded; use a previously uploaded file via its file_id or specify a URL. On success, the edited Message is returned.
Fields
chat_id: ChatIdUnique identifier for the target chat or username of the target channel (in the format @channelusername)
message_id: i64Identifier of the message to edit
media: InputMediaA JSON-serialized object for a new media content of the message
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for a new inline keyboard.
Implementations
Sourceimpl EditMessageMedia
impl EditMessageMedia
Sourcepub fn new(
chat_id: impl Into<ChatId>,
message_id: i64,
media: impl Into<InputMedia>,
) -> Self
pub fn new( chat_id: impl Into<ChatId>, message_id: i64, media: impl Into<InputMedia>, ) -> Self
Create a new editMessageMedia request
Sourcepub fn with_reply_markup(self, markup: impl Into<InlineKeyboardMarkup>) -> Self
pub fn with_reply_markup(self, markup: impl Into<InlineKeyboardMarkup>) -> Self
Set reply markup