Struct telbot_types::message::Location[][src]

pub struct Location {
    pub longitude: f32,
    pub latitude: f32,
    pub horizontal_accuracy: Option<f32>,
    pub live_period: Option<i32>,
    pub heading: Option<i32>,
    pub proximity_alert_radius: Option<i32>,
}
This object represents a point on the map.

Fields

longitude: f32

Longitude as defined by sender

latitude: f32

Latitude as defined by sender

horizontal_accuracy: Option<f32>

The radius of uncertainty for the location, measured in meters; 0-1500

live_period: Option<i32>

Time relative to the message sending date, during which the location can be updated, in seconds. For active live locations only.

heading: Option<i32>

The direction in which user is moving, in degrees; 1-360. For active live locations only.

proximity_alert_radius: Option<i32>

Maximum distance for proximity alerts about approaching another chat member, in meters. For sent live locations only.