pub struct SendContact {
pub chat_id: ChatId,
pub phone_number: String,
pub first_name: String,
pub last_name: Option<String>,
pub vcard: Option<String>,
pub disable_notification: Option<bool>,
pub reply_to_message_id: Option<i64>,
pub allow_sending_without_reply: Option<bool>,
pub reply_markup: Option<ReplyMarkup>,
pub protect_content: Option<bool>,
}Expand description
Use this method to send text messages. On success, the sent Message is returned.
Fields
chat_id: ChatIdUnique identifier for the target chat or username of the target channel (in the format @channelusername)
phone_number: StringContact’s phone number
first_name: StringContact’s first name
last_name: Option<String>Contact’s last name
vcard: Option<String>Additional data about the contact in the form of a vCard, 0-2048 bytes
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
reply_to_message_id: Option<i64>If the message is a reply, ID of the original message
allow_sending_without_reply: Option<bool>Pass True, if the message should be sent even if the specified replied-to message is not found
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
protect_content: Option<bool>Protects the contents of the sent message from forwarding and saving
Implementations
Sourceimpl SendContact
impl SendContact
Sourcepub fn new(
chat_id: impl Into<ChatId>,
phone_number: impl Into<String>,
first_name: impl Into<String>,
) -> Self
pub fn new( chat_id: impl Into<ChatId>, phone_number: impl Into<String>, first_name: impl Into<String>, ) -> Self
Create a new sendContact request
Sourcepub fn with_last_name(self, last_name: impl Into<String>) -> Self
pub fn with_last_name(self, last_name: impl Into<String>) -> Self
Set last name
Sourcepub fn with_vcard(self, vcard: impl Into<String>) -> Self
pub fn with_vcard(self, vcard: impl Into<String>) -> Self
Set vcard
Sourcepub fn disable_notification(self) -> Self
pub fn disable_notification(self) -> Self
Disable notification
Sourcepub fn allow_sending_without_reply(self) -> Self
pub fn allow_sending_without_reply(self) -> Self
Allow sending message even if the replying message isn’t present
Sourcepub fn with_reply_markup(self, markup: impl Into<ReplyMarkup>) -> Self
pub fn with_reply_markup(self, markup: impl Into<ReplyMarkup>) -> Self
Set reply markup
Sourcepub fn protect_content(self) -> Self
pub fn protect_content(self) -> Self
Protect content