pub struct SendDice {
pub chat_id: ChatId,
pub emoji: Option<String>,
pub disable_notification: Option<bool>,
pub reply_to_message_id: Option<i64>,
pub allow_sending_without_reply: Option<bool>,
pub reply_markup: Option<ReplyMarkup>,
pub protect_content: Option<bool>,
}Expand description
Use this method to send an animated emoji that will display a random value. On success, the sent Message is returned.
Fields
chat_id: ChatIdUnique identifier for the target chat or username of the target channel (in the format @channelusername)
emoji: Option<String>Emoji on which the dice throw animation is based. Currently, must be one of “🎲”, “🎯”, “🏀”, “⚽”, “🎳”, or “🎰”. Dice can have values 1-6 for “🎲”, “🎯” and “🎳”, values 1-5 for “🏀” and “⚽”, and values 1-64 for “🎰”. Defaults to “🎲”
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
reply_to_message_id: Option<i64>If the message is a reply, ID of the original message
allow_sending_without_reply: Option<bool>Pass True, if the message should be sent even if the specified replied-to message is not found
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
protect_content: Option<bool>Protects the contents of the sent message from forwarding and saving
Implementations
Sourceimpl SendDice
impl SendDice
Sourcepub fn with_emoji(self, emoji: impl Into<String>) -> Self
pub fn with_emoji(self, emoji: impl Into<String>) -> Self
Set emoji
Sourcepub fn disable_notification(self) -> Self
pub fn disable_notification(self) -> Self
Disable notification
Sourcepub fn allow_sending_without_reply(self) -> Self
pub fn allow_sending_without_reply(self) -> Self
Allow sending message even if the replying message isn’t present
Sourcepub fn with_reply_markup(self, markup: impl Into<ReplyMarkup>) -> Self
pub fn with_reply_markup(self, markup: impl Into<ReplyMarkup>) -> Self
Set reply markup
Sourcepub fn protect_content(self) -> Self
pub fn protect_content(self) -> Self
Protect content