SendMediaGroup

Struct SendMediaGroup 

pub struct SendMediaGroup {
    pub chat_id: ChatId,
    pub media: Vec<InputMedia>,
    pub disable_notification: Option<bool>,
    pub reply_to_message_id: Option<i64>,
    pub allow_sending_without_reply: Option<bool>,
    pub protect_content: Option<bool>,
}
Use this method to send a group of photos, videos, documents or audios as an album. Documents and audio files can be only grouped in an album with messages of the same type. On success, an array of Messages that were sent is returned.

Fields

chat_id: ChatId

Unique identifier for the target chat or username of the target channel (in the format @channelusername)

media: Vec<InputMedia>

A JSON-serialized array describing messages to be sent, must include 2-10 items

disable_notification: Option<bool>

Sends the message silently. Users will receive a notification with no sound.

reply_to_message_id: Option<i64>

If the message is a reply, ID of the original message

allow_sending_without_reply: Option<bool>

Pass True, if the message should be sent even if the specified replied-to message is not found

protect_content: Option<bool>

Protects the contents of the sent message from forwarding and saving

Implementations

Source

impl SendMediaGroup

pub fn new(chat_id: impl Into<ChatId>) -> Self

Create a new sendMediaGroup request

pub fn with_media_group(self, media_group: Vec<InputMedia>) -> Self

Set media group

pub fn with_media(self, media: impl Into<InputMedia>) -> Self

Add one media file

pub fn disable_notification(self) -> Self

Disable notification

pub fn reply_to(self, message_id: i64) -> Self

Reply to message

pub fn allow_sending_without_reply(self) -> Self

Allow sending message even if the replying message isn’t present

pub fn protect_content(self) -> Self

Protect content