SendPhoto

Struct SendPhoto 

pub struct SendPhoto {
    pub chat_id: ChatId,
    pub photo: InputFileVariant,
    pub caption: Option<String>,
    pub parse_mode: Option<ParseMode>,
    pub caption_entities: Option<Vec<MessageEntity>>,
    pub disable_notification: Option<bool>,
    pub reply_to_message_id: Option<i64>,
    pub allow_sending_without_reply: Option<bool>,
    pub reply_markup: Option<ReplyMarkup>,
    pub protect_content: Option<bool>,
}
Use this method to send photos. On success, the sent Message is returned.

Fields

chat_id: ChatId

Unique identifier for the target chat or username of the target channel (in the format @channelusername)

photo: InputFileVariant

Photo to send. Pass a file_id as String to send a photo that exists on the Telegram servers (recommended), pass an HTTP URL as a String for Telegram to get a photo from the Internet, or upload a new photo using multipart/form-data. The photo must be at most 10 MB in size. The photo’s width and height must not exceed 10000 in total. Width and height ratio must be at most 20. More info on Sending Files »

caption: Option<String>

Photo caption (may also be used when resending photos by file_id), 0-1024 characters after entities parsing

parse_mode: Option<ParseMode>

Mode for parsing entities in the message text. See formatting options for more details.

caption_entities: Option<Vec<MessageEntity>>

List of special entities that appear in the caption, which can be specified instead of parse_mode

disable_notification: Option<bool>

Sends the message silently. Users will receive a notification with no sound.

reply_to_message_id: Option<i64>

If the message is a reply, ID of the original message

allow_sending_without_reply: Option<bool>

Pass True, if the message should be sent even if the specified replied-to message is not found

reply_markup: Option<ReplyMarkup>

Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.

protect_content: Option<bool>

Protects the contents of the sent message from forwarding and saving

Implementations

Source

impl SendPhoto

pub fn new( chat_id: impl Into<ChatId>, photo: impl Into<InputFileVariant>, ) -> Self

Create a new sendPhoto request

pub fn with_caption(self, caption: impl Into<String>) -> Self

Set caption

pub fn with_parse_mode(self, parse_mode: ParseMode) -> Self

Set parse mode

pub fn with_entities(self, entities: Vec<MessageEntity>) -> Self

Set caption entities

pub fn with_entity(self, entity: MessageEntity) -> Self

Add one entity

pub fn disable_notification(self) -> Self

Disable notification

pub fn reply_to(self, message_id: i64) -> Self

Reply to message

pub fn allow_sending_without_reply(self) -> Self

Allow sending message even if the replying message isn’t present

pub fn with_reply_markup(self, markup: impl Into<ReplyMarkup>) -> Self

Set reply markup

pub fn protect_content(self) -> Self

Protect content