Struct telbot_types::message::SendVenue[][src]

pub struct SendVenue {
Show 13 fields pub chat_id: ChatId, pub latitude: f32, pub longitude: f32, pub title: String, pub address: String, pub foursquare_id: Option<String>, pub foursquare_type: Option<String>, pub google_place_id: Option<String>, pub google_place_type: Option<String>, pub disable_notification: Option<bool>, pub reply_to_message_id: Option<i64>, pub allow_sending_without_reply: Option<bool>, pub reply_markup: Option<ReplyMarkup>,
}
Use this method to send information about a venue. On success, the sent Message is returned.

Fields

chat_id: ChatId

Unique identifier for the target chat or username of the target channel (in the format @channelusername)

latitude: f32

Latitude of the venue

longitude: f32

Longitude of the venue

title: String

Name of the venue

address: String

Address of the venue

foursquare_id: Option<String>

Foursquare identifier of the venue, if known

foursquare_type: Option<String>

Foursquare type of the venue, if known. (For example, “arts_entertainment/default”, “arts_entertainment/aquarium” or “food/icecream”.)

google_place_id: Option<String>

Google Places identifier of the venue

google_place_type: Option<String>

Google Places type of the venue. (See supported types.)

disable_notification: Option<bool>

Sends the message silently. Users will receive a notification with no sound.

reply_to_message_id: Option<i64>

If the message is a reply, ID of the original message

allow_sending_without_reply: Option<bool>

Pass True, if the message should be sent even if the specified replied-to message is not found

reply_markup: Option<ReplyMarkup>

Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.

Implementations

Create a new sendVenue request

Set foursquare id and type

Set google place id and type

Disable notification

Reply to message

Allow sending message even if the replying message isn’t present

Set reply markup