Struct telbot_types::message::StopMessageLiveLocation [−][src]
pub struct StopMessageLiveLocation {
pub target: ChatOrInlineMessage,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to stop updating a live location message before live_period expires. On success, if the edited message is not an inline message, the edited Message is returned, otherwise True is returned.
Fields
target: ChatOrInlineMessageIdentifier of the message to edit
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for a new inline keyboard.
Implementations
Create a new stopMessageLiveLocation request from chat message id
Create a new stopMessageLiveLocation request from inline message id
Set reply markup