pub struct StopPoll {
pub chat_id: ChatId,
pub message_id: i64,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to stop a poll which was sent by the bot. On success, the stopped Poll is returned.
Fields
chat_id: ChatIdUnique identifier for the target chat or username of the target channel (in the format @channelusername)
message_id: i64Identifier of the original message with the poll
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for a new inline keyboard.
Implementations