pub struct VoiceChatParticipantsInvited {
pub users: Option<Vec<User>>,
}Expand description
This object represents a service message about new members invited to a voice chat.
Fields
users: Option<Vec<User>>New members that were invited to the voice chat