Struct telbot_types::payment::SuccessfulPayment[][src]

pub struct SuccessfulPayment {
    pub currency: String,
    pub total_amount: i32,
    pub invoice_payload: String,
    pub shipping_option_id: Option<String>,
    pub order_info: Option<OrderInfo>,
    pub telegram_payment_charge_id: String,
    pub provider_payment_charge_id: String,
}
This object contains basic information about a successful payment.

Fields

currency: String

Three-letter ISO 4217 currency code

total_amount: i32

Total price in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).

invoice_payload: String

Bot specified invoice payload

shipping_option_id: Option<String>

Identifier of the shipping option chosen by the user

order_info: Option<OrderInfo>

Order info provided by the user

telegram_payment_charge_id: String

Telegram payment identifier

provider_payment_charge_id: String

Provider payment identifier