Module query

Module query 

Structs

AnswerCallbackQuery
Use this method to send answers to callback queries sent from inline keyboards. The answer will be displayed to the user as a notification at the top of the chat screen or as an alert. On success, True is returned.
AnswerInlineQuery
Use this method to send answers to an inline query. On success, True is returned. No more than 50 results per query are allowed.
CallbackQuery
This object represents an incoming callback query from a callback button in an inline keyboard.
ChosenInlineResult
InlineQuery
This object represents an incoming inline query. When the user sends an empty query, your bot could return some default or trending results.
InlineQueryResult
This object represents one result of an inline query.

Enums

InlineQueryResultKind
Inline query result type
InputMessageContent
This object represents the content of a message to be sent as a result of an inline query.