pub struct Sticker {
pub file_id: String,
pub file_unique_id: String,
pub width: u32,
pub height: u32,
pub is_animated: bool,
pub thumb: Option<PhotoSize>,
pub emoji: Option<String>,
pub set_name: Option<String>,
pub mask_position: Option<MaskPosition>,
pub file_size: Option<u32>,
}Expand description
This object represents a sticker.
Fields
file_id: StringIdentifier for this file, which can be used to download or reuse the file
file_unique_id: StringUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
width: u32Sticker width
height: u32Sticker height
is_animated: boolTrue, if the sticker is animated
thumb: Option<PhotoSize>Sticker thumbnail in the .WEBP or .JPG format
emoji: Option<String>Emoji associated with the sticker
set_name: Option<String>Name of the sticker set to which the sticker belongs
mask_position: Option<MaskPosition>For mask stickers, the position where the mask should be placed
file_size: Option<u32>File size