Module update

Module update 

Structs

GetUpdates
Use this method to receive incoming updates using long polling (wiki).
Update
This object represents an incoming update. At most one of the optional parameters can be present in any given update.

Enums

UpdateKind
Update type