pub enum UpdateKind {
Show 13 variants
Message {
message: Message,
},
EditedMessage {
edited_message: Message,
},
ChannelPost {
channel_post: Message,
},
EditedChannelPost {
edited_channel_post: Message,
},
InlineQuery {
inline_query: InlineQuery,
},
ChosenInlineResult {
chosen_inline_result: ChosenInlineResult,
},
CallbackQuery {
callback_query: CallbackQuery,
},
ShippingQuery {
shipping_query: ShippingQuery,
},
PreCheckoutQuery {
pre_checkout_query: PreCheckoutQuery,
},
Poll {
poll: Poll,
},
PollAnswer {
poll_answer: PollAnswer,
},
MyChatMemberUpdated {
my_chat_member: ChatMemberUpdated,
},
ChatMemberUpdated {
chat_member: ChatMemberUpdated,
},
}Expand description
Update type
Variants
Message
New incoming message of any kind — text, photo, sticker, etc.
EditedMessage
New version of a message that is known to the bot and was edited
ChannelPost
New incoming channel post of any kind — text, photo, sticker, etc.
EditedChannelPost
New version of a channel post that is known to the bot and was edited
InlineQuery
New incoming inline query
Fields
inline_query: InlineQueryChosenInlineResult
The result of an inline query that was chosen by a user and sent to their chat partner. Please see Telegram’s documentation on the feedback collecting for details on how to enable these updates for your bot.
Fields
chosen_inline_result: ChosenInlineResultCallbackQuery
New incoming callback query
Fields
callback_query: CallbackQueryShippingQuery
New incoming shipping query. Only for invoices with flexible price
Fields
shipping_query: ShippingQueryPreCheckoutQuery
New incoming pre-checkout query. Contains full information about checkout
Fields
pre_checkout_query: PreCheckoutQueryPoll
New poll state. Bots receive only updates about stopped polls and polls, which are sent by the bot
PollAnswer
A user changed their answer in a non-anonymous poll. Bots receive new votes only in polls that were sent by the bot itself.
Fields
poll_answer: PollAnswerMyChatMemberUpdated
The bot’s chat member status was updated in a chat. For private chats, this update is received only when the bot is blocked or unblocked by the user.
Fields
my_chat_member: ChatMemberUpdatedChatMemberUpdated
A chat member’s status was updated in a chat. The bot must be an administrator in the chat and must explicitly specify “chat_member” in the list of allowed_updates to receive these updates.
Fields
chat_member: ChatMemberUpdated