GetUpdates

Struct GetUpdates 

pub struct GetUpdates {
    pub offset: Option<i32>,
    pub limit: Option<u32>,
    pub timeout: Option<u32>,
    pub allowed_updates: Option<Vec<String>>,
}
Use this method to receive incoming updates using long polling (wiki).

Fields

offset: Option<i32>

Identifier of the first update to be returned. Must be greater by one than the highest among the identifiers of previously received updates. By default, updates starting with the earliest unconfirmed update are returned. An update is considered confirmed as soon as getUpdates is called with an offset higher than its update_id. The negative offset can be specified to retrieve updates starting from -offset update from the end of the updates queue. All previous updates will forgotten.

limit: Option<u32>

Limits the number of updates to be retrieved. Values between 1-100 are accepted. Defaults to 100.

timeout: Option<u32>

Timeout in seconds for long polling. Defaults to 0, i.e. usual short polling. Should be positive, short polling should be used for testing purposes only.

allowed_updates: Option<Vec<String>>

A JSON-serialized list of the update types you want your bot to receive. For example, specify [“message”, “edited_channel_post”, “callback_query”] to only receive updates of these types. See Update for a complete list of available update types. Specify an empty list to receive all update types except chat_member (default). If not specified, the previous setting will be used.

Please note that this parameter doesn’t affect updates created before the call to the getUpdates, so unwanted updates may be received for a short period of time.

Implementations

Source

impl GetUpdates

pub fn new() -> Self

Create a new getUpdates request

pub fn with_offset(self, offset: i32) -> Self

Set offset

pub fn with_limit(self, limit: u32) -> Self

Set limit

pub fn with_timeout(self, timeout: u32) -> Self

Set timeout

pub fn with_allowed_updates(self, updates: Vec<String>) -> Self

Set allowed updates

pub fn with_allowed_update(self, update: impl Into<String>) -> Self

Add one allowed update