Update

Struct Update 

pub struct Update {
    pub update_id: u32,
    pub kind: UpdateKind,
}
This object represents an incoming update. At most one of the optional parameters can be present in any given update.

Fields

update_id: u32

The update’s unique identifier. Update identifiers start from a certain positive number and increase sequentially. This ID becomes especially handy if you’re using Webhooks, since it allows you to ignore repeated updates or to restore the correct update sequence, should they get out of order. If there are no new updates for at least a week, then identifier of the next update will be chosen randomly instead of sequentially.

kind: UpdateKind

Update type