Module webhook

Module webhook 

Structs

DeleteWebhook
Use this method to remove webhook integration if you decide to switch back to getUpdates. Returns True on success.
GetWebhookInfo
Use this method to get current webhook status. Requires no parameters. On success, returns a WebhookInfo object. If the bot is using getUpdates, will return an object with the url field empty.
SetWebhook
Use this method to specify a url and receive incoming updates via an outgoing webhook. Whenever there is an update for the bot, we will send an HTTPS POST request to the specified url, containing a JSON-serialized Update. In case of an unsuccessful request, we will give up after a reasonable amount of attempts. Returns True on success.
WebhookInfo
Contains information about the current status of a webhook.