Use this method to close the bot instance before moving it from one local server to another.
You need to delete the webhook before calling this method to ensure that the bot isn’t launched again after server restart.
The method will return error 429 in the first 10 minutes after the bot is launched.
Returns True on success. Requires no parameters.
Use this method to delete the list of the bot’s commands for the given scope and user language.
After deletion, higher level commands will be shown to affected users.
Returns True on success.
Use this method to get the current list of the bot’s commands for the given scope and user language.
Returns Array of BotCommand on success.
If commands aren’t set, an empty list is returned.
Use this method to change the list of the bot’s commands. See https://core.telegram.org/bots#commands for more details about bot commands.
Returns True on success.