Module telbot_types::bot [−][src]
Structs
This object represents a bot command.
Use this method to close the bot instance before moving it from one local server to another. You need to delete the webhook before calling this method to ensure that the bot isn’t launched again after server restart. The method will return error 429 in the first 10 minutes after the bot is launched. Returns True on success. Requires no parameters.
A simple method for testing your bot’s auth token. Requires no parameters.
Use this method to log out from the cloud Bot API server before launching the bot locally.
Enums
This object represents the scope to which bot commands are applied.