pub struct GetMyCommands {
pub scope: Option<BotCommandScope>,
pub language_code: Option<String>,
}Expand description
Use this method to get the current list of the bot’s commands for the given scope and user language. Returns Array of BotCommand on success. If commands aren’t set, an empty list is returned.
Fields
scope: Option<BotCommandScope>A JSON-serialized object, describing scope of users for which the commands are relevant. Defaults to BotCommandScopeDefault.
language_code: Option<String>A two-letter ISO 639-1 language code. If empty, commands will be applied to all users from the given scope, for whose language there are no dedicated commands
Implementations
Sourceimpl GetMyCommands
impl GetMyCommands
Sourcepub fn with_scope(self, scope: BotCommandScope) -> Self
pub fn with_scope(self, scope: BotCommandScope) -> Self
Set command scope
Sourcepub fn with_language_code(self, language_code: impl Into<String>) -> Self
pub fn with_language_code(self, language_code: impl Into<String>) -> Self
Set language code