Use this method to approve a chat join request.
The bot must be an administrator in the chat for this to work and must have the can_invite_users administrator right.
Returns True on success.
Use this method to ban a user in a group, a supergroup or a channel.
In the case of supergroups and channels, the user will not be able to return to the chat
on their own using invite links, etc., unless unbanned first.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Returns True on success.
Use this method to create an additional invite link for a chat.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
The link can be revoked using the method revokeChatInviteLink.
Returns the new invite link as ChatInviteLink object.
Use this method to decline a chat join request.
The bot must be an administrator in the chat for this to work and must have the can_invite_users administrator right.
Returns True on success.
Use this method to delete a chat photo.
Photos can’t be changed for private chats.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Returns True on success.
Use this method to delete a group sticker set from a supergroup.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Use the field can_set_sticker_set optionally returned in getChat requests to check if the bot can use this method.
Returns True on success.
Use this method to edit a non-primary invite link created by the bot.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Returns the edited invite link as a ChatInviteLink object.
Use this method to generate a new primary invite link for a chat;
any previously generated primary link is revoked.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Returns the new invite link as String on success.
Use this method to get up to date information about the chat
(current name of the user for one-on-one conversations, current username of a user, group or channel, etc.).
Returns a Chat object on success.
Use this method to get a list of administrators in a chat.
On success, returns an Array of ChatMember objects
that contains information about all chat administrators except other bots.
If the chat is a group or a supergroup and no administrators were appointed, only the creator will be returned.
Use this method to add a message to the list of pinned messages in a chat.
If the chat is not a private chat, the bot must be an administrator in the chat for this to work
and must have the ‘can_pin_messages’ administrator right in a supergroup or ‘can_edit_messages’ administrator right in a channel.
Returns True on success.
Use this method to promote or demote a user in a supergroup or a channel.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Pass False for all boolean parameters to demote a user.
Returns True on success.
Use this method to restrict a user in a supergroup.
The bot must be an administrator in the supergroup for this to work and must have the appropriate administrator rights.
Pass True for all permissions to lift restrictions from a user.
Returns True on success.
Use this method to revoke an invite link created by the bot.
If the primary link is revoked, a new link is automatically generated.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Returns the revoked invite link as ChatInviteLink object.
Use this method to change the description of a group, a supergroup or a channel.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Returns True on success.
Use this method to set default chat permissions for all members.
The bot must be an administrator in the group or a supergroup for this to work and must have the can_restrict_members administrator rights.
Returns True on success.
Use this method to set a new profile photo for the chat.
Photos can’t be changed for private chats.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Returns True on success.
Use this method to set a new group sticker set for a supergroup.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Use the field can_set_sticker_set optionally returned in getChat requests to check if the bot can use this method.
Returns True on success.
Use this method to change the title of a chat.
Titles can’t be changed for private chats.
The bot must be an administrator in the chat for this to work and must have the appropriate administrator rights.
Returns True on success.
Use this method to unban a previously banned user in a supergroup or channel.
The user will not return to the group or channel automatically, but will be able to join via link, etc.
The bot must be an administrator for this to work.
By default, this method guarantees that after the call the user is not a member of the chat, but will be able to join it.
So if the user is a member of the chat they will also be removed from the chat.
If you don’t want this, use the parameter only_if_banned.
Returns True on success.
Use this method to clear the list of pinned messages in a chat.
If the chat is not a private chat, the bot must be an administrator in the chat for this to work
and must have the ‘can_pin_messages’ administrator right in a supergroup or ‘can_edit_messages’ administrator right in a channel.
Returns True on success.
Use this method to remove a message from the list of pinned messages in a chat.
If the chat is not a private chat, the bot must be an administrator in the chat for this to work
and must have the ‘can_pin_messages’ administrator right in a supergroup or ‘can_edit_messages’ administrator right in a channel.
Returns True on success.