Module telbot_types::chat[][src]

Structs

This object represents a chat.

Represents an invite link for a chat.

This object represents changes in the status of a chat member.

Describes actions that a non-administrator user is allowed to take in a chat.

This object represents a chat photo.

Enums

Chat identifier