Struct telbot_types::chat::Chat[][src]

pub struct Chat {
Show 18 fields pub id: i64, pub kind: ChatKind, pub title: Option<String>, pub username: Option<String>, pub first_name: Option<String>, pub last_name: Option<String>, pub photo: Option<ChatPhoto>, pub bio: Option<String>, pub description: Option<String>, pub invite_link: Option<String>, pub pinned_message: Option<Box<Message>>, pub permissions: Option<ChatPermissions>, pub slow_mode_delay: Option<i32>, pub message_auto_delete_time: Option<i32>, pub sticker_set_name: Option<String>, pub can_get_sticker_set: Option<bool>, pub linked_chat_id: Option<i32>, pub location: Option<ChatLocation>,
}
This object represents a chat.

Fields

id: i64

Unique identifier for this chat.

kind: ChatKind

Type of chat.

title: Option<String>

Title, for supergroups, channels and group chats

username: Option<String>

Username, for private chats, supergroups and channels if available

first_name: Option<String>

First name of the other party in a private chat

last_name: Option<String>

Last name of the other party in a private chat

photo: Option<ChatPhoto>

Chat photo. Returned only in getChat.

bio: Option<String>

Bio of the other party in a private chat. Returned only in getChat.

description: Option<String>

Description, for groups, supergroups and channel chats. Returned only in getChat.

invite_link: Option<String>

Primary invite link, for groups, supergroups and channel chats. Returned only in getChat.

pinned_message: Option<Box<Message>>

The most recent pinned message (by sending date). Returned only in getChat.

permissions: Option<ChatPermissions>

Default chat member permissions, for groups and supergroups. Returned only in getChat.

slow_mode_delay: Option<i32>

Default chat member permissions, for groups and supergroups. Returned only in getChat.

message_auto_delete_time: Option<i32>

The time after which all messages sent to the chat will be automatically deleted; in seconds. Returned only in getChat.

sticker_set_name: Option<String>

For supergroups, name of group sticker set. Returned only in getChat.

can_get_sticker_set: Option<bool>

True, if the bot can change the group sticker set. Returned only in getChat.

linked_chat_id: Option<i32>

Unique identifier for the linked chat, i.e. the discussion group identifier for a channel and vice versa; for supergroups and channel chats. Returned only in getChat.

location: Option<ChatLocation>

For supergroups, the location to which the supergroup is connected. Returned only in getChat.