Struct telbot_types::chat::ChatInviteLink [−][src]
pub struct ChatInviteLink {
pub invite_link: String,
pub creator: User,
pub is_primary: bool,
pub is_revoked: bool,
pub expire_date: Option<u64>,
pub member_limit: Option<u32>,
}Expand description
Represents an invite link for a chat.
Fields
invite_link: StringThe invite link. If the link was created by another chat administrator, then the second part of the link will be replaced with “…”.
creator: UserCreator of the link
is_primary: boolTrue, if the link is primary
is_revoked: boolTrue, if the link is revoked
expire_date: Option<u64>Point in time (Unix timestamp) when the link will expire or has been expired
member_limit: Option<u32>Maximum number of users that can be members of the chat simultaneously after joining the chat via this invite link; 1-99999