Struct telbot_types::chat::ChatMemberUpdated [−][src]
pub struct ChatMemberUpdated {
pub chat: Chat,
pub from: User,
pub date: u64,
pub old_chat_member: ChatMember,
pub new_chat_member: ChatMember,
pub invite_link: Option<ChatInviteLink>,
}Expand description
This object represents changes in the status of a chat member.
Fields
chat: ChatChat the user belongs to
from: UserPerformer of the action, which resulted in the change
date: u64Date the change was done in Unix time
old_chat_member: ChatMemberPrevious information about the chat member
new_chat_member: ChatMemberNew information about the chat member
invite_link: Option<ChatInviteLink>Chat invite link, which was used by the user to join the chat; for joining by invite link events only.