Module markup

Module markup 

Structs

CallbackGame
A placeholder, currently holds no information. Use BotFather to set up your game.
ForceReply
Upon receiving a message with this object, Telegram clients will display a reply interface to the user (act as if the user has selected the bot’s message and tapped ‘Reply’).
InlineKeyboardButton
This object represents one button of an inline keyboard.
InlineKeyboardMarkup
This object represents an inline keyboard that appears right next to the message it belongs to.
InlineKeyboardRow
KeyboardButton
This object represents one button of the reply keyboard. For simple text buttons String can be used instead of this object to specify text of the button. Optional fields request_contact, request_location, and request_poll are mutually exclusive.
KeyboardButtonPollType
This object represents type of a poll, which is allowed to be created and sent when the corresponding button is pressed.
LoginUrl
This object represents a parameter of the inline keyboard button used to automatically authorize a user.
MessageEntity
This object represents one special entity in a text message.
ReplyKeyboardMarkup
This object represents a custom keyboard with reply options (see Introduction to bots for details and examples).
ReplyKeyboardRemove
Upon receiving a message with this object, Telegram clients will remove the current custom keyboard and display the default letter-keyboard.

Enums

InlineKeyboardButtonKind
Inline keyboard button type
MessageEntityKind
Type of the message entity
ParseMode
ReplyMarkup
Reply markups