Module telbot_types::markup [−][src]
Structs
A placeholder, currently holds no information. Use BotFather to set up your game.
Upon receiving a message with this object, Telegram clients will display a reply interface to the user (act as if the user has selected the bot’s message and tapped ‘Reply’).
This object represents one button of an inline keyboard.
This object represents an inline keyboard that appears right next to the message it belongs to.
This object represents one button of the reply keyboard. For simple text buttons String can be used instead of this object to specify text of the button. Optional fields request_contact, request_location, and request_poll are mutually exclusive.
This object represents type of a poll, which is allowed to be created and sent when the corresponding button is pressed.
This object represents a parameter of the inline keyboard button used to automatically authorize a user.
This object represents one special entity in a text message.
This object represents a custom keyboard with reply options (see Introduction to bots for details and examples).
Upon receiving a message with this object, Telegram clients will remove the current custom keyboard and display the default letter-keyboard.
Enums
Inline keyboard button type
Type of the message entity
Reply markups