pub enum InlineKeyboardButtonKind {
Url {
url: String,
},
Login {
login_url: LoginUrl,
},
Callback {
callback_data: String,
},
SwitchInlineQuery {
switch_inline_query: String,
},
SwitchInlineQueryCurrentChat {
switch_inline_query_current_chat: String,
},
CallbackGame {
callback_game: CallbackGame,
},
Pay {
pay: bool,
},
}Expand description
Inline keyboard button type
Variants
Url
Login
Fields
login_url: LoginUrlAn HTTP URL used to automatically authorize the user. Can be used as a replacement for the Telegram Login Widget.
Callback
Fields
callback_data: StringData to be sent in a callback query to the bot when button is pressed, 1-64 bytes
SwitchInlineQuery
Fields
switch_inline_query: StringIf set, pressing the button will prompt the user to select one of their chats, open that chat and insert the bot’s username and the specified inline query in the input field. Can be empty, in which case just the bot’s username will be inserted.
Note: This offers an easy way for users to start using your bot in inline mode when they are currently in a private chat with it. Especially useful when combined with switch_pm… actions – in this case the user will be automatically returned to the chat they switched from, skipping the chat selection screen.
SwitchInlineQueryCurrentChat
Fields
switch_inline_query_current_chat: StringIf set, pressing the button will insert the bot’s username and the specified inline query in the current chat’s input field. Can be empty, in which case only the bot’s username will be inserted.
This offers a quick way for the user to open your bot in inline mode in the same chat – good for selecting something from multiple options.
CallbackGame
Fields
callback_game: CallbackGameDescription of the game that will be launched when the user presses the button.
NOTE: This type of button must always be the first button in the first row.
Pay
Implementations
Sourceimpl InlineKeyboardButtonKind
impl InlineKeyboardButtonKind
pub fn url(&self) -> Option<&str>
pub fn login_url(&self) -> Option<&LoginUrl>
pub fn callback_data(&self) -> Option<&str>
pub fn inline_query_prompt(&self) -> Option<&str>
pub fn inline_query_current_chat_prompt(&self) -> Option<&str>
pub fn is_url(&self) -> bool
pub fn is_login(&self) -> bool
pub fn is_callback(&self) -> bool
pub fn is_switch_inline_query(&self) -> bool
pub fn is_switch_inline_query_current_chat(&self) -> bool
pub fn is_callback_game(&self) -> bool
pub fn is_pay(&self) -> bool