Use this method to copy messages of any kind.
Service messages and invoice messages can’t be copied.
The method is analogous to the method forwardMessage, but the copied message doesn’t have a link to the original message.
Returns the MessageId of the sent message on success.
Use this method to edit live location messages.
A location can be edited until its live_period expires
or editing is explicitly disabled by a call to stopMessageLiveLocation.
On success, True is returned.
Use this method to edit animation, audio, document, photo, or video messages.
If a message is part of a message album, then it can be edited only to an audio for audio albums,
only to a document for document albums and to a photo or a video otherwise.
When an inline message is edited, a new file can’t be uploaded;
use a previously uploaded file via its file_id or specify a URL.
On success, True is returned.
Use this method to edit live location messages.
A location can be edited until its live_period expires
or editing is explicitly disabled by a call to stopMessageLiveLocation.
On success, the edited Message is returned.
Use this method to edit animation, audio, document, photo, or video messages.
If a message is part of a message album, then it can be edited only to an audio for audio albums,
only to a document for document albums and to a photo or a video otherwise.
When an inline message is edited, a new file can’t be uploaded;
use a previously uploaded file via its file_id or specify a URL.
On success, the edited Message is returned.
Use this method to edit text and game messages.
On success, if the edited message is not an inline message, the edited Message is returned,
otherwise True is returned.
Use this method to send animation files (GIF or H.264/MPEG-4 AVC video without sound).
On success, the sent Message is returned.
Bots can currently send video files of up to 50 MB in size, this limit may be changed in the future.
Use this method to send audio files, if you want Telegram clients to display them in the music player.
Your audio must be in the .MP3 or .M4A format.
On success, the sent Message is returned.
Use this method when you need to tell the user that something is happening on the bot’s side.
The status is set for 5 seconds or less (when a message arrives from your bot, Telegram clients clear its typing status).
Returns True on success.
Use this method to send general files. On success, the sent Message is returned.
Bots can currently send files of any type of up to 50 MB in size, this limit may be changed in the future.
Use this method to send a group of photos, videos, documents or audios as an album. Documents and audio files can be only grouped in an album with messages of the same type.
On success, an array of Messages that were sent is returned.
Use this method to send video files, Telegram clients support mp4 videos (other formats may be sent as Document).
On success, the sent Message is returned.
Bots can currently send video files of up to 50 MB in size, this limit may be changed in the future.
As of v.4.0, Telegram clients support rounded square mp4 videos of up to 1 minute long.
Use this method to send video messages.
On success, the sent Message is returned.
Use this method to send audio files, if you want Telegram clients to display the file as a playable voice message.
For this to work, your audio must be in an .OGG file encoded with OPUS
(other formats may be sent as Audio or Document).
On success, the sent Message is returned.
Bots can currently send video files of up to 50 MB in size, this limit may be changed in the future.