pub enum PollKind {
Regular,
Quiz {
correct_option_id: Option<usize>,
explanation: Option<String>,
explanation_entities: Option<Vec<MessageEntity>>,
},
}Expand description
Poll type
Variants
Regular
Quiz
Fields

correct_option_id: Option<usize>0-based identifier of the correct answer option. Available only for polls in the quiz mode, which are closed, or was sent (not forwarded) by the bot or to the private chat with the bot.

explanation: Option<String>Text that is shown when a user chooses an incorrect answer or taps on the lamp icon in a quiz-style poll, 0-200 characters

explanation_entities: Option<Vec<MessageEntity>>Special entities like usernames, URLs, bot commands, etc. that appear in the explanation
Implementations
Sourceimpl PollKind
impl PollKind
pub fn correct_option_id(&self) -> Option<usize>
pub fn explanation(&self) -> Option<&str>
pub fn explanation_entities(&self) -> Option<&[MessageEntity]>
pub fn is_regular(&self) -> bool
pub fn is_quiz(&self) -> bool