pub struct SendAudio {Show 14 fields
pub chat_id: ChatId,
pub audio: InputFileVariant,
pub duration: Option<u32>,
pub performer: Option<String>,
pub title: Option<String>,
pub thumb: Option<InputFileVariant>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub disable_notification: Option<bool>,
pub reply_to_message_id: Option<i64>,
pub allow_sending_without_reply: Option<bool>,
pub reply_markup: Option<ReplyMarkup>,
pub protect_content: Option<bool>,
}Expand description
Use this method to send audio files, if you want Telegram clients to display them in the music player. Your audio must be in the .MP3 or .M4A format. On success, the sent Message is returned.
For sending voice messages, use the sendVoice method instead.
Fields
chat_id: ChatIdUnique identifier for the target chat or username of the target channel (in the format @channelusername)
audio: InputFileVariantAudio file to send. Pass a file_id as String to send an audio file that exists on the Telegram servers (recommended), pass an HTTP URL as a String for Telegram to get an audio file from the Internet, or upload a new one using multipart/form-data. More info on Sending Files »
duration: Option<u32>Duration of the audio in seconds
performer: Option<String>Performer
title: Option<String>Track name
thumb: Option<InputFileVariant>Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail’s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>.
caption: Option<String>Audio caption, 0-1024 characters after entities parsing
parse_mode: Option<ParseMode>Mode for parsing entities in the message text. See formatting options for more details.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be specified instead of parse_mode
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
reply_to_message_id: Option<i64>If the message is a reply, ID of the original message
allow_sending_without_reply: Option<bool>Pass True, if the message should be sent even if the specified replied-to message is not found
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
protect_content: Option<bool>Protects the contents of the sent message from forwarding and saving
Implementations
Sourceimpl SendAudio
impl SendAudio
Sourcepub fn new(
chat_id: impl Into<ChatId>,
audio: impl Into<InputFileVariant>,
) -> Self
pub fn new( chat_id: impl Into<ChatId>, audio: impl Into<InputFileVariant>, ) -> Self
Create a new sendAudio request
Sourcepub fn with_duration(self, duration: u32) -> Self
pub fn with_duration(self, duration: u32) -> Self
Set duration
Sourcepub fn with_performer(self, performer: impl Into<String>) -> Self
pub fn with_performer(self, performer: impl Into<String>) -> Self
Set performer
Sourcepub fn with_title(self, title: impl Into<String>) -> Self
pub fn with_title(self, title: impl Into<String>) -> Self
Set title
Sourcepub fn with_thumbnail(self, thumbnail: impl Into<InputFileVariant>) -> Self
pub fn with_thumbnail(self, thumbnail: impl Into<InputFileVariant>) -> Self
Set thumbnail
Sourcepub fn with_caption(self, caption: impl Into<String>) -> Self
pub fn with_caption(self, caption: impl Into<String>) -> Self
Set caption
Sourcepub fn with_parse_mode(self, parse_mode: ParseMode) -> Self
pub fn with_parse_mode(self, parse_mode: ParseMode) -> Self
Set parse mode
Sourcepub fn with_entities(self, entities: Vec<MessageEntity>) -> Self
pub fn with_entities(self, entities: Vec<MessageEntity>) -> Self
Set caption entities
Sourcepub fn with_entity(self, entity: MessageEntity) -> Self
pub fn with_entity(self, entity: MessageEntity) -> Self
Add one entity
Sourcepub fn disable_notification(self) -> Self
pub fn disable_notification(self) -> Self
Disable notification
Sourcepub fn allow_sending_without_reply(self) -> Self
pub fn allow_sending_without_reply(self) -> Self
Allow sending message even if the replying message isn’t present
Sourcepub fn with_reply_markup(self, markup: impl Into<ReplyMarkup>) -> Self
pub fn with_reply_markup(self, markup: impl Into<ReplyMarkup>) -> Self
Set reply markup
Sourcepub fn protect_content(self) -> Self
pub fn protect_content(self) -> Self
Protect content