Struct telbot_types::message::SendContact[][src]

pub struct SendContact {
    pub chat_id: ChatId,
    pub phone_number: String,
    pub first_name: String,
    pub last_name: Option<String>,
    pub vcard: Option<String>,
    pub disable_notification: Option<bool>,
    pub reply_to_message_id: Option<i64>,
    pub allow_sending_without_reply: Option<bool>,
    pub reply_markup: Option<ReplyMarkup>,
}
Use this method to send text messages. On success, the sent Message is returned.

Fields

chat_id: ChatId

Unique identifier for the target chat or username of the target channel (in the format @channelusername)

phone_number: String

Contact’s phone number

first_name: String

Contact’s first name

last_name: Option<String>

Contact’s last name

vcard: Option<String>

Additional data about the contact in the form of a vCard, 0-2048 bytes

disable_notification: Option<bool>

Sends the message silently. Users will receive a notification with no sound.

reply_to_message_id: Option<i64>

If the message is a reply, ID of the original message

allow_sending_without_reply: Option<bool>

Pass True, if the message should be sent even if the specified replied-to message is not found

reply_markup: Option<ReplyMarkup>

Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.

Implementations

Create a new sendContact request

Set last name

Set vcard

Disable notification

Reply to message

Allow sending message even if the replying message isn’t present

Set reply markup