Struct telbot_types::message::SendDice[][src]

pub struct SendDice {
    pub chat_id: ChatId,
    pub emoji: Option<String>,
    pub disable_notification: Option<bool>,
    pub reply_to_message_id: Option<i64>,
    pub allow_sending_without_reply: Option<bool>,
    pub reply_markup: Option<ReplyMarkup>,
}
Use this method to send an animated emoji that will display a random value. On success, the sent Message is returned.

Fields

chat_id: ChatId

Unique identifier for the target chat or username of the target channel (in the format @channelusername)

emoji: Option<String>

Emoji on which the dice throw animation is based. Currently, must be one of “🎲”, “🎯”, “🏀”, “⚽”, “🎳”, or “🎰”. Dice can have values 1-6 for “🎲”, “🎯” and “🎳”, values 1-5 for “🏀” and “⚽”, and values 1-64 for “🎰”. Defaults to “🎲”

disable_notification: Option<bool>

Sends the message silently. Users will receive a notification with no sound.

reply_to_message_id: Option<i64>

If the message is a reply, ID of the original message

allow_sending_without_reply: Option<bool>

Pass True, if the message should be sent even if the specified replied-to message is not found

reply_markup: Option<ReplyMarkup>

Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.

Implementations

Create a new sendDice request.

Set emoji

Disable notification

Reply to message

Allow sending message even if the replying message isn’t present

Set reply markup