Struct telbot_types::message::SendMediaGroup[][src]

pub struct SendMediaGroup {
    pub chat_id: ChatId,
    pub media: Vec<InputMedia>,
    pub disable_notification: Option<bool>,
    pub reply_to_message_id: Option<i64>,
    pub allow_sending_without_reply: Option<bool>,
}
Use this method to send a group of photos, videos, documents or audios as an album. Documents and audio files can be only grouped in an album with messages of the same type. On success, an array of Messages that were sent is returned.

Fields

chat_id: ChatId

Unique identifier for the target chat or username of the target channel (in the format @channelusername)

media: Vec<InputMedia>

A JSON-serialized array describing messages to be sent, must include 2-10 items

disable_notification: Option<bool>

Sends the message silently. Users will receive a notification with no sound.

reply_to_message_id: Option<i64>

If the message is a reply, ID of the original message

allow_sending_without_reply: Option<bool>

Pass True, if the message should be sent even if the specified replied-to message is not found

Implementations

Create a new sendMediaGroup request

Set media group

Add one media file

Disable notification

Reply to message

Allow sending message even if the replying message isn’t present