Struct telbot_types::message::VoiceChatScheduled[][src]

pub struct VoiceChatScheduled {
    pub start_date: u64,
}
This object represents a service message about a voice chat scheduled in the chat.

Fields

start_date: u64

Point in time (Unix timestamp) when the voice chat is supposed to be started by a chat administrator