Struct telbot_types::payment::Invoice [−][src]
pub struct Invoice {
pub title: String,
pub description: String,
pub start_parameter: String,
pub currency: String,
pub total_amount: i32,
}Expand description
This object contains basic information about an invoice.
Fields
title: StringProduct name
description: StringProduct description
start_parameter: StringUnique bot deep-linking parameter that can be used to generate this invoice
currency: StringThree-letter ISO 4217 currency code
total_amount: i32Total price in the smallest units of the currency (integer, not float/double).
For example, for a price of US$ 1.45 pass amount = 145.
See the exp parameter in currencies.json,
it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).