Module telbot_types::update[][src]

Structs

Use this method to receive incoming updates using long polling (wiki).

This object represents an incoming update. At most one of the optional parameters can be present in any given update.

Enums

Update type