User

Struct User 

pub struct User {
    pub id: i64,
    pub is_bot: bool,
    pub first_name: String,
    pub last_name: Option<String>,
    pub username: Option<String>,
    pub language_code: Option<String>,
    pub can_join_groups: Option<bool>,
    pub can_read_all_group_messages: Option<bool>,
    pub supports_inline_queries: Option<bool>,
}
This object represents a Telegram user or bot.

Fields

id: i64

Unique identifier for this user or bot.

is_bot: bool

True, if this user is a bot

first_name: String

User’s or bot’s first name

last_name: Option<String>

User’s or bot’s last name

username: Option<String>

User’s or bot’s username

language_code: Option<String>

IETF language tag of the user’s language

can_join_groups: Option<bool>

True, if the bot can be invited to groups. Returned only in getMe.

can_read_all_group_messages: Option<bool>

True, if privacy mode is disabled for the bot. Returned only in getMe.

supports_inline_queries: Option<bool>

True, if the bot supports inline queries. Returned only in getMe.

Implementations

Source

impl User

pub fn get_profile_photos(&self) -> GetUserProfilePhotos

pub fn ban_from(&self, chat_id: impl Into<ChatId>) -> BanChatMember

pub fn unban_from(&self, chat_id: impl Into<ChatId>) -> UnbanChatMember

pub fn restrict_from( &self, chat_id: impl Into<ChatId>, permissions: ChatPermissions, ) -> RestrictChatMember

pub fn promote_from(&self, chat_id: impl Into<ChatId>) -> PromoteChatMember

pub fn set_administrator_title_from( &self, chat_id: impl Into<ChatId>, custom_title: impl Into<String>, ) -> SetChatAdministratorCustomTitle

pub fn approve_join_to( &self, chat_id: impl Into<ChatId>, ) -> ApproveChatJoinRequest

pub fn decline_join_to( &self, chat_id: impl Into<ChatId>, ) -> DeclineChatJoinRequest

pub fn get_member_from(&self, chat_id: impl Into<ChatId>) -> GetChatMember